@@ -3,7 +3,7 @@ module Main (main) where
 import Control.DeepSeq
 import Criterion.Main
 import Data.Text (Text)
-import qualified Data.Text as T
+import Data.Text qualified as T
 import Data.Text.Metrics
 
 main :: IO ()
@@ -21,7 +21,7 @@ main =
     ]
 
 -- | Produce benchmark group to test.
-btmetric :: NFData a => String -> (Text -> Text -> a) -> Benchmark
+btmetric :: (NFData a) => String -> (Text -> Text -> a) -> Benchmark
 btmetric name f = bgroup name (bs <$> stdSeries)
   where
     bs n = env (return (testData n, testData n)) (bench (show n) . nf (uncurry f))
